import unittest

from gou2tool.util.company_util import CompanyUtil


class TestDemo(unittest.TestCase):
    def test_name(self):
        company_list = [
            "台山市台城向日葵美业工作室（个体工商户）",
            "北京美宸伟业住房租赁有限责任公司",
            "大连美林达企业管理咨询有限公司",
            "佛山美林达企业管理咨询有限公司",
            "上海美林达企业管理咨询有限公司",
            "海口诺美施企业管理有限公司",
            "经开区悦己美业店（个体工商户）",
            "昆明倾诚悦秀美业品牌管理有限公司第一分公司",
            "青岛澜绮美业科技有限公司",
            "上海白钥美品农业发展有限公司",
            "宁波市鄞州中河美丁酒业商行（个体工商户）",
        ]
        for company in company_list:
            print(CompanyUtil.name(company), "=>", company)
        self.assertTrue(True)


if __name__ == '__main__':
    unittest.main()



import time
from datetime import datetime, timedelta


class DateUtil:
    """日期工具类"""

    @staticmethod
    def date(format_str='%Y-%m-%d %H:%M:%S', timestamp=None):
        """
        获取当前时间或指定时间戳的格式化日期

        Args:
            format_str: 日期格式，默认为 '%Y-%m-%d %H:%M:%S'
            timestamp: 时间戳，None表示当前时间

        Returns:
            str: 格式化后的日期字符串
        """
        if timestamp is None:
            return datetime.now().strftime(format_str)
        else:
            return datetime.fromtimestamp(timestamp).strftime(format_str)

    @staticmethod
    def now(format_str='%Y-%m-%d %H:%M:%S', timestamp=None):
        """
        获取当前时间或指定时间戳的格式化日期（别名方法）

        Args:
            format_str: 日期格式，默认为 '%Y-%m-%d %H:%M:%S'
            timestamp: 时间戳，None表示当前时间

        Returns:
            str: 格式化后的日期字符串
        """
        return DateUtil.date(format_str, timestamp)

    @staticmethod
    def current_microseconds():
        """
        获取当前时间的微秒部分

        Returns:
            int: 微秒数
        """
        return int((time.time() - int(time.time())) * 1000000)

    @staticmethod
    def date_with_microseconds(format_str='%Y-%m-%d %H:%M:%S.%f', microtime=None):
        """
        格式化包含微秒的时间

        Args:
            format_str: 日期格式，默认为 '%Y-%m-%d %H:%M:%S.%f'
            microtime: 微秒时间戳，None表示当前时间

        Returns:
            str: 格式化后的时间（包含微秒）
        """
        if microtime is None:
            microtime = time.time()

        dt = datetime.fromtimestamp(microtime)
        return dt.strftime(format_str)

    @staticmethod
    def date_cn():
        """
        获取中文格式的当前日期时间

        Returns:
            str: 中文格式的日期时间
        """
        return datetime.now().strftime('%Y年%m月%d日 %H时%M分%S秒')

    @staticmethod
    def current():
        """
        获取当前时间的时间戳（毫秒）

        Returns:
            int: 当前时间毫秒数
        """
        return int(round(time.time() * 1000))

    @staticmethod
    def current_seconds():
        """
        获取当前时间的时间戳（秒）

        Returns:
            int: 当前时间秒数
        """
        return int(time.time())

    @staticmethod
    def first_day_of_month(year=None, month=None, format_str='%Y-%m-%d'):
        """
        获取指定月份的第一天

        Args:
            year: 年份，默认为当前年份
            month: 月份，默认为当前月份
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            str: 指定月份第一天日期
        """
        if year is None:
            year = datetime.now().year
        if month is None:
            month = datetime.now().month

        dt = datetime(year, month, 1)
        return dt.strftime(format_str)

    @staticmethod
    def last_day_of_month(year=None, month=None, format_str='%Y-%m-%d'):
        """
        获取指定月份的最后一天

        Args:
            year: 年份，默认为当前年份
            month: 月份，默认为当前月份
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            str: 指定月份最后一天日期
        """
        if year is None:
            year = datetime.now().year
        if month is None:
            month = datetime.now().month

        # 下个月第一天减一天就是本月最后一天
        if month == 12:
            next_month = datetime(year + 1, 1, 1)
        else:
            next_month = datetime(year, month + 1, 1)

        last_day = next_month.replace(day=1) - timedelta(days=1)
        return last_day.strftime(format_str)

    @staticmethod
    def first_day_of_year(year=None, format_str='%Y-%m-%d'):
        """
        获取指定年份的第一天

        Args:
            year: 年份，默认为当前年份
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            str: 指定年份第一天日期
        """
        if year is None:
            year = datetime.now().year

        dt = datetime(year, 1, 1)
        return dt.strftime(format_str)

    @staticmethod
    def last_day_of_year(year=None, format_str='%Y-%m-%d'):
        """
        获取指定年份的最后一天

        Args:
            year: 年份，默认为当前年份
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            str: 指定年份最后一天日期
        """
        if year is None:
            year = datetime.now().year

        dt = datetime(year, 12, 31)
        return dt.strftime(format_str)

    @staticmethod
    def first_day_of_week(year=None, week=None, format_str='%Y-%m-%d'):
        """
        获取指定周的第一天（周一）

        Args:
            year: 年份，默认为当前年份
            week: 周数，默认为当前周
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            str: 指定周第一天日期
        """
        if year is None:
            year = datetime.now().year
        if week is None:
            week = datetime.now().isocalendar()[1]

        # 计算该年第1周的周一
        jan_4 = datetime(year, 1, 4)  # 该年第一个周四
        first_monday = jan_4 - timedelta(days=jan_4.weekday())
        target_monday = first_monday + timedelta(weeks=week - 1)

        return target_monday.strftime(format_str)

    @staticmethod
    def last_day_of_week(year=None, week=None, format_str='%Y-%m-%d'):
        """
        获取指定周的最后一天（周日）

        Args:
            year: 年份，默认为当前年份
            week: 周数，默认为当前周
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            str: 指定周最后一天日期
        """
        if year is None:
            year = datetime.now().year
        if week is None:
            week = datetime.now().isocalendar()[1]

        # 计算该年第1周的周一
        jan_4 = datetime(year, 1, 4)  # 该年第一个周四
        first_monday = jan_4 - timedelta(days=jan_4.weekday())
        target_sunday = first_monday + timedelta(weeks=week - 1, days=6)

        return target_sunday.strftime(format_str)

    @staticmethod
    def today_number(with_leading_zero=True):
        """
        获取今天是几号

        Args:
            with_leading_zero: 是否补零，默认True

        Returns:
            str: 今天的日期号码
        """
        if with_leading_zero:
            return datetime.now().strftime('%d')
        else:
            return datetime.now().strftime('%-d')

    @staticmethod
    def day_number(timestamp=None, with_leading_zero=True):
        """
        获取指定时间戳是几号

        Args:
            timestamp: 时间戳，默认为当前时间
            with_leading_zero: 是否补零，默认True

        Returns:
            str: 指定时间的日期号码
        """
        if timestamp is None:
            timestamp = time.time()

        dt = datetime.fromtimestamp(timestamp)
        if with_leading_zero:
            return dt.strftime('%d')
        else:
            return dt.strftime('%-d')

    @staticmethod
    def is_today(date_param=None, format_str='%Y-%m-%d'):
        """
        判断指定日期是否为今天

        Args:
            date_param: 日期参数，可以是日期字符串、时间戳或None（默认为当前时间）
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            bool: 如果指定日期是今天则返回True，否则返回False
        """
        today = datetime.now().strftime(format_str)

        if date_param is None:
            check_date = today
        elif isinstance(date_param, (int, float)):
            check_date = datetime.fromtimestamp(date_param).strftime(format_str)
        else:
            check_date = datetime.strptime(str(date_param), format_str).strftime(format_str)

        return today == check_date

    @staticmethod
    def is_yesterday(date_param=None, format_str='%Y-%m-%d'):
        """
        判断指定日期是否为昨天

        Args:
            date_param: 日期参数，可以是日期字符串、时间戳或None（默认为当前时间）
            format_str: 日期格式，默认为 '%Y-%m-%d'

        Returns:
            bool: 如果指定日期是昨天则返回True，否则返回False
        """
        yesterday = (datetime.now() - timedelta(days=1)).strftime(format_str)

        if date_param is None:
            check_date = datetime.now().strftime(format_str)
        elif isinstance(date_param, (int, float)):
            check_date = datetime.fromtimestamp(date_param).strftime(format_str)
        else:
            check_date = datetime.strptime(str(date_param), format_str).strftime(format_str)

        return yesterday == check_date



import re


class CompanyUtil:

    @staticmethod
    def name(value):
        """
        提取企业名称的核心部分，去除城市省份前缀、括号内容和企业后缀
        """
        if not value:
            return ""

        result = value

        # 1. 移除括号内的内容（如个体工商户、分支机构等）
        result = re.sub(r'[（(][^）)]*[)）]', '', result).strip()

        # 2. 移除分公司信息
        result = re.sub(r'第.+?分公司', '', result).strip()

        # 3. 移除城市/地区前缀（常见的地名开头）
        city_prefixes = [
            r'^北京市', r'^上海市', r'^天津市', r'^重庆市',
            r'^[\u4e00-\u9fa5]+省',  # 省份
            r'^[\u4e00-\u9fa5]+市',  # 城市
            r'^[\u4e00-\u9fa5]+区',  # 区县
            r'^[\u4e00-\u9fa5]+县',  # 县
            r'^[\u4e00-\u9fa5]+自治州',
            r'^[\u4e00-\u9fa5]+地区',
            r'^[\u4e00-\u9fa5]+盟',
            r'^经济技术开发区',
            r'^经开区',
            r'^北京', r'^上海', r'^天津', r'^重庆', r'^武汉', r'^襄阳', r'^南京', r'^长沙', r'^岳阳', r'^大连',
            r'^佛山', r'^海口', r'^西安', r'^长春', r'^郑州', r'^石家庄', r'^太原', r'^合肥', r'^南昌', r'^贵阳',
            r'^昆明', r'^拉萨', r'^银川', r'^拉萨', r'^兰州', r'^乌鲁木齐', r'^拉萨', r'^青岛', r'^均川', r'^随州',
            r'^潜江', r'^仙桃', r'^天门'
        ]

        # 按长度降序排列，确保优先匹配较长的前缀
        sorted_city_prefixes = sorted(city_prefixes, key=lambda x: len(x), reverse=True)

        for prefix in sorted_city_prefixes:
            result = re.sub(prefix, '', result).strip()

        # 4. 移除常见的企业后缀
        suffixes = [
            r'有限责任公司$', r'有限公司$', r'股份有限公司$',
            r'责任公司$', r'责任有限公司$', r'责任投资$', r'投资$',
            r'投资集团$', r'投资有限公司$', r'投资咨询$', r'投资机构$',
            r'科技有限公司', r'企业管理咨询$',
            r'企业管理咨询有限公司', r'品牌管理', r'农业发展',
            r'咨询', r'管理', r'教育', r'教育咨询', r'教育机构',
            r'教育咨询机构', r'酒业', r'企业管理有限公司', r'住房租赁',
            r'公司$', r'工作室$', r'商行$', r'店$', r'中心$',
            r'企业$', r'集团$', r'合作社$', r'酒业商行$', r'美业工作室$',
            r'美业品牌管理有限公司$', r'美容店$', r'美容美甲店$', r'美容养生会馆$',
            r'中式美容院$', r'化妆品店$', r'美容美甲工作室$', r'养生馆$', r'护肤中心$',
            r'康美容馆$', r'美颜中心$', r'化妆品销售店$', r'美容美体店$', r'美发店$',
            r'美容中心$', r'养生保健馆$', r'美甲店$', r'保健馆$', r'美容养生馆$',
            r'烫染造型室$', r'美容有限公司$', r'门诊部$', r'诊所$', r'美容诊所有限公司$',
            r'理发店$', r'健康管理中心$'
        ]

        # 按长度降序排列，确保优先匹配较长的后缀
        sorted_suffixes = sorted(suffixes, key=lambda x: len(x), reverse=True)

        for suffix in sorted_suffixes:
            result = re.sub(suffix, '', result).strip()

        return result if result else value
